# Generated by Django 5.1.6 on 2025-02-21 10:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0002_rename_cancellation_reason_request_other_service_description'),
    ]

    operations = [
        migrations.AddField(
            model_name='request',
            name='status_cancel',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
    ]
