# Generated by Django 5.1.6 on 2025-02-21 06:21

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0001_initial'),
    ]

    operations = [
        migrations.RenameField(
            model_name='request',
            old_name='cancellation_reason',
            new_name='other_service_description',
        ),
    ]
